[![pypi](https://img.shields.io/pypi/v/psweep?color=blue)](https://pypi.org/project/psweep)
![GitHub Workflow Status](https://img.shields.io/github/actions/workflow/status/elcorto/psweep/tests.yml?branch=master&label=tests)
[![DOI](https://zenodo.org/badge/92956212.svg)](https://zenodo.org/badge/latestdoi/92956212)

![](doc/source/psweep-logo.png)

This package helps you to set up and run parameter studies.

Mostly, you'll start with a script and a for-loop and ask "why do I
need a package for that"? Well, soon you'll want housekeeping tools
and a database for your runs and results. This package exists because
sooner or later, everyone doing parameter scans arrives at roughly the
same workflow and tools.

**Check the [docs here](https://elcorto.github.io/psweep)**.
